import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';


const svg = select('svg');

// const width = +svg.attr('width');
const width = +svg.attr('width') / 3;
const height = +svg.attr('height');


//===========================================
const render1 = data => {
  const xValue = d => d.suspiciousness;
  const yValue = d => d.id;
  const margin = { top: 20, right: 30, bottom: 120, left: 40 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  g.append('g')
    .call(axisLeft(yScale))
  	.select('.domain')
  	//.selectAll('.domain, .tick line')
  		.remove();
  
  
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  	
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  
  g.append('text')
  	.attr('y', -5)
  	.text('Suspicousness (Top 25 Lines)');
  
  
  
};



//===========================================
const render2 = data => {
  const xValue = d => d.recency;
  const yValue = d => d.id;
  const margin = { top: 20, right: 30, bottom: 120, left: 0};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left + width},${margin.top})`);
  
 g.append('g')
    .call(axisLeft(yScale))
  	.select('.domain')
  	//.selectAll('.domain, .tick line')
  		.remove();
  
  
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth());
  
  g.append('text')
  	.attr('y', -5)
  	.text('Recency');
};

const margin = { top: 20, right: 40, bottom: 120, left: 0};
var render3_svg_g1=svg.append('g').attr('transform', `translate(${margin.left + (2 * width)},${margin.top})`);
var render3_svg_x=render3_svg_g1.append('g');
var render3_svg_y=render3_svg_g1.append('g');
//===========================================
const render3 = data => {
  const xValue = d => d.line_complexity;
  const yValue = (d,i)=> (i+1);

 
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth])
  	.clamp(true);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = render3_svg_g1;
  
  render3_svg_y.call(axisLeft(yScale))
  	.select('.domain')
  	//.selectAll('.domain, .tick line')
  		.remove();
  
  render3_svg_x.call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  var prev=g.selectAll('rect');
  g.selectAll('rect').data(data)
    .enter().append('rect')
  .merge(prev)
      .attr('y', function(d,i){return yScale(yValue(d,i))})
      .attr('width', function(d){console.log(d);return xScale(xValue(d))})
      .attr('height', yScale.bandwidth());

   g.append('text')
  	.attr('y', -5)
  	.text('Line Complexity');
  
  // g.append('rect')
  // 		.attr('y', -20)
  //   	.attr('width', 10)
  // 		.attr('height', 10);
  
d3.select("#sort")
  .on("click", function() {
		data.sort(function(a,b) {
      return xScale(b.line_complexity)-xScale(a.line_complexity);
    });

  render3(data);
});
  
};



csv('data.csv').then(data => {
  data.forEach(d => {
    d.suspiciousness = +d.suspiciousness;
    d.recency = +d.recency;
    d.line_complexity = +d.line_complexity;
  });
  render1(data);
  render2(data);
  render3(data);
});

